# NuRadioReco
Reconstruction framework for radio detectors of high-energy neutrinos

Please see

Glaser, C., Nelles, A., Plaisier, I. et al. Eur. Phys. J. C (2019) 79: 464. https://doi.org/10.1140/epjc/s10052-019-6971-5

for a peer-reviewed description. Please reference this article, if you use NuRadioReco for your analysis. 

For installation instructions and additional information please see the https://github.com/nu-radio/NuRadioReco/wiki
